@import url("pyramid.css");
@import url('https://fonts.googleapis.com/css2?family=Lora:ital,wght@0,400;0,500;0,600;0,700;1,400;1,500;1,600;1,700&display=swap');
@import url('https://fonts.googleapis.com/css2?family=Roboto+Mono:wght@200;300;400;500;600;700&display=swap');

body {
    font-family: "Lora", sans-serif;
    font-size: 18px;
}

pre, .pre, code {
    font-size: 1em;
    font-family: "Roboto Mono", monospace;
}
code.any, code.any .pre {
    font-family: "Lora", sans-serif;
}
div.body p, div.body dd, div.body li {
    line-height: 1.5rem;
}

div.body {
    min-width: 700px;
    max-width: 1200px;
}

h1 a.toc-backref,
h2 a.toc-backref,
h3 a.toc-backref,
h4 a.toc-backref,
h5 a.toc-backref {
    color: initial;
}

h1 a.toc-backref:hover,
h2 a.toc-backref:hover,
h3 a.toc-backref:hover,
h4 a.toc-backref:hover,
h5 a.toc-backref:hover {
    color: #1b61d6;
}
